@@ -317,16 +317,19 @@ PyObject* igraphmodule_VertexSeq_get_attribute_values_mapping(igraphmodule_Verte
   }
 
   /* Handle strings according to the mapping protocol */
-  if (PyBaseString_Check(o))
+  if (PyBaseString_Check(o)) {
     return igraphmodule_VertexSeq_get_attribute_values(self, o);
+  }
 
   /* Handle iterables and slices by calling the select() method */
   if (PySlice_Check(o) || PyObject_HasAttrString(o, "__iter__")) {
     PyObject *result, *args;
-    args = Py_BuildValue("(O)", o);
+    args = PyTuple_Pack(1, o);
 
-    if (!args)
+    if (!args) {
       return NULL;
+    }
+
     result = igraphmodule_VertexSeq_select(self, args);
     Py_DECREF(args);
     return result;
@@ -585,17 +588,18 @@ PyObject* igraphmodule_VertexSeq_select(igraphmodule_VertexSeqObject *self,
   igraphmodule_VertexSeqObject *result;
   igraphmodule_GraphObject *gr;
   igraph_integer_t igraph_idx;
+  igraph_bool_t working_on_whole_graph = igraph_vs_is_all(&self->vs);
+  igraph_vector_t v, v2;
   long i, j, n, m;
 
-  gr=self->gref;
-  result=igraphmodule_VertexSeq_copy(self);
-  if (result==0)
+  gr = self->gref;
+  result = igraphmodule_VertexSeq_copy(self);
+  if (result == 0)
     return NULL;
 
   /* First, filter by positional arguments */
   n = PyTuple_Size(args);
-
-  for (i=0; i<n; i++) {
+  for (i = 0; i < n; i++) {
     PyObject *item = PyTuple_GET_ITEM(args, i);
 
     if (item == Py_None) {
@@ -603,7 +607,7 @@ PyObject* igraphmodule_VertexSeq_select(igraphmodule_VertexSeqObject *self,
       igraph_vs_destroy(&result->vs);
       igraph_vs_none(&result->vs);
       /* We can simply bail out here */
-      return (PyObject*)result;
+      return (PyObject*) result;
     } else if (PyCallable_Check(item)) {
       /* Call the callable for every vertex in the current sequence to
        * determine what's up */
@@ -616,7 +620,7 @@ PyObject* igraphmodule_VertexSeq_select(igraphmodule_VertexSeqObject *self,
       }
 
       m = PySequence_Size((PyObject*)result);
-      for (j=0; j<m; j++) {
+      for (j = 0; j < m; j++) {
         PyObject *vertex = PySequence_GetItem((PyObject*)result, j);
         PyObject *call_result;
         if (vertex == 0) {
@@ -630,10 +634,12 @@ PyObject* igraphmodule_VertexSeq_select(igraphmodule_VertexSeqObject *self,
           igraph_vector_destroy(&v);
           return NULL;
         }
-        if (PyObject_IsTrue(call_result))
+        if (PyObject_IsTrue(call_result)) {
           igraph_vector_push_back(&v,
             igraphmodule_Vertex_get_index_long((igraphmodule_VertexObject*)vertex));
-        else was_excluded=1;
+        } else {
+          was_excluded = 1;
+        }
         Py_DECREF(call_result);
         Py_DECREF(vertex);
       }
@@ -655,61 +661,80 @@ PyObject* igraphmodule_VertexSeq_select(igraphmodule_VertexSeqObject *self,
        * to restrict the vertex set. Integers are interpreted as indices on the
        * vertex set and NOT on the original, untouched vertex sequence of the
        * graph */
-      igraph_vector_t v, v2;
       if (igraph_vector_init(&v, 0)) {
         igraphmodule_handle_igraph_error();
         return 0;
       }
-      if (igraph_vector_init(&v2, 0)) {
-        igraph_vector_destroy(&v);
-        igraphmodule_handle_igraph_error();
-        return 0;
+
+      if (!working_on_whole_graph) {
+        /* Extract the current vertex sequence into a vector */
+        if (igraph_vector_init(&v2, 0)) {
+          igraph_vector_destroy(&v);
+          igraphmodule_handle_igraph_error();
+          return 0;
+        }
+        if (igraph_vs_as_vector(&gr->g, self->vs, &v2)) {
+          igraph_vector_destroy(&v);
+          igraph_vector_destroy(&v2);
+          igraphmodule_handle_igraph_error();
+          return 0;
+        }
+        m = igraph_vector_size(&v2);
+      } else {
+        /* v2 left uninitialized, we are not going to use it as it would
+         * simply contain integers from 0 to vcount(g)-1 */
+        m = igraph_vcount(&gr->g);
       }
-      if (igraph_vs_as_vector(&gr->g, self->vs, &v2)) {
-        igraph_vector_destroy(&v);
-        igraph_vector_destroy(&v2);
-        igraphmodule_handle_igraph_error();
-        return 0;
-      }
-      m = igraph_vector_size(&v2);
-      for (; i<n; i++) {
+
+      for (; i < n; i++) {
         PyObject *item2 = PyTuple_GET_ITEM(args, i);
         long idx;
         if (!PyLong_Check(item2)) {
           Py_DECREF(result);
           PyErr_SetString(PyExc_TypeError, "vertex indices expected");
           igraph_vector_destroy(&v);
-          igraph_vector_destroy(&v2);
+          if (!working_on_whole_graph) {
+            igraph_vector_destroy(&v2);
+          }
           return NULL;
         }
         idx = PyLong_AsLong(item2);
         if (idx >= m || idx < 0) {
           PyErr_SetString(PyExc_ValueError, "vertex index out of range");
           igraph_vector_destroy(&v);
-          igraph_vector_destroy(&v2);
+          if (!working_on_whole_graph) {
+            igraph_vector_destroy(&v2);
+          }
           return NULL;
         }
-        if (igraph_vector_push_back(&v, VECTOR(v2)[idx])) {
+        if (igraph_vector_push_back(&v, working_on_whole_graph ? idx : VECTOR(v2)[idx])) {
           Py_DECREF(result);
           igraphmodule_handle_igraph_error();
           igraph_vector_destroy(&v);
-          igraph_vector_destroy(&v2);
+          if (!working_on_whole_graph) {
+            igraph_vector_destroy(&v2);
+          }
           return NULL;
         }
       }
-      igraph_vector_destroy(&v2);
+
+      if (!working_on_whole_graph) {
+        igraph_vector_destroy(&v2);
+      }
+
       igraph_vs_destroy(&result->vs);
+
       if (igraph_vs_vector_copy(&result->vs, &v)) {
         Py_DECREF(result);
         igraphmodule_handle_igraph_error();
         igraph_vector_destroy(&v);
         return NULL;
       }
+
       igraph_vector_destroy(&v);
     } else {
       /* Iterators, slices and everything that was not handled directly */
       PyObject *iter=0, *item2;
-      igraph_vector_t v, v2;
 
       /* Allocate stuff */
       if (igraph_vector_init(&v, 0)) {
@@ -717,20 +742,28 @@ PyObject* igraphmodule_VertexSeq_select(igraphmodule_VertexSeqObject *self,
         Py_DECREF(result);
         return 0;
       }
-      if (igraph_vector_init(&v2, 0)) {
-        igraph_vector_destroy(&v);
-        Py_DECREF(result);
-        igraphmodule_handle_igraph_error();
-        return 0;
+
+      if (!working_on_whole_graph) {
+        /* Extract the current vertex sequence into a vector */
+        if (igraph_vector_init(&v2, 0)) {
+          igraph_vector_destroy(&v);
+          Py_DECREF(result);
+          igraphmodule_handle_igraph_error();
+          return 0;
+        }
+        if (igraph_vs_as_vector(&gr->g, self->vs, &v2)) {
+          igraph_vector_destroy(&v);
+          igraph_vector_destroy(&v2);
+          Py_DECREF(result);
+          igraphmodule_handle_igraph_error();
+          return 0;
+        }
+        m = igraph_vector_size(&v2);
+      } else {
+        /* v2 left uninitialized, we are not going to use it as it would
+         * simply contain integers from 0 to vcount(g)-1 */
+        m = igraph_vcount(&gr->g);
       }
-      if (igraph_vs_as_vector(&gr->g, self->vs, &v2)) {
-        igraph_vector_destroy(&v);
-        igraph_vector_destroy(&v2);
-        Py_DECREF(result);
-        igraphmodule_handle_igraph_error();
-        return 0;
-      }
-      m = igraph_vector_size(&v2);
 
       /* Create an appropriate iterator */
       if (PySlice_Check(item)) {
@@ -739,7 +772,7 @@ PyObject* igraphmodule_VertexSeq_select(igraphmodule_VertexSeqObject *self,
         PyObject* range;
         igraph_bool_t ok;
 
-        ok = (PySlice_GetIndicesEx(item, igraph_vector_size(&v2), &start, &stop, &step, &sl) == 0);
+        ok = (PySlice_GetIndicesEx(item, m, &start, &stop, &step, &sl) == 0);
         if (ok) {
           range = igraphmodule_PyRange_create(start, stop, step);
           ok = (range != 0);
@@ -751,7 +784,9 @@ PyObject* igraphmodule_VertexSeq_select(igraphmodule_VertexSeqObject *self,
         }
         if (!ok) {
           igraph_vector_destroy(&v);
-          igraph_vector_destroy(&v2);
+          if (!working_on_whole_graph) {
+            igraph_vector_destroy(&v2);
+          }
           PyErr_SetString(PyExc_TypeError, "error while converting slice to iterator");
           Py_DECREF(result);
           return 0;
@@ -764,13 +799,16 @@ PyObject* igraphmodule_VertexSeq_select(igraphmodule_VertexSeqObject *self,
       /* Did we manage to get an iterator? */
       if (iter == 0) {
         igraph_vector_destroy(&v);
-        igraph_vector_destroy(&v2);
+        if (!working_on_whole_graph) {
+          igraph_vector_destroy(&v2);
+        }
         PyErr_SetString(PyExc_TypeError, "invalid vertex filter among positional arguments");
         Py_DECREF(result);
         return 0;
       }
+
       /* Do the iteration */
-      while ((item2=PyIter_Next(iter)) != 0) {
+      while ((item2 = PyIter_Next(iter)) != 0) {
         if (igraphmodule_PyObject_to_integer_t(item2, &igraph_idx)) {
           /* We simply ignore elements that we don't know */
           Py_DECREF(item2);
@@ -781,34 +819,45 @@ PyObject* igraphmodule_VertexSeq_select(igraphmodule_VertexSeqObject *self,
             Py_DECREF(result);
             Py_DECREF(iter);
             igraph_vector_destroy(&v);
-            igraph_vector_destroy(&v2);
+            if (!working_on_whole_graph) {
+              igraph_vector_destroy(&v2);
+            }
             return NULL;
           }
-          if (igraph_vector_push_back(&v, VECTOR(v2)[(long int) igraph_idx])) {
+          if (igraph_vector_push_back(&v, working_on_whole_graph ? igraph_idx : VECTOR(v2)[(long int) igraph_idx])) {
             Py_DECREF(result);
             Py_DECREF(iter);
             igraphmodule_handle_igraph_error();
             igraph_vector_destroy(&v);
-            igraph_vector_destroy(&v2);
+            if (!working_on_whole_graph) {
+              igraph_vector_destroy(&v2);
+            }
             return NULL;
           }
         }
       }
+
       /* Deallocate stuff */
-      igraph_vector_destroy(&v2);
+      if (!working_on_whole_graph) {
+        igraph_vector_destroy(&v2);
+      }
+
       Py_DECREF(iter);
       if (PyErr_Occurred()) {
         igraph_vector_destroy(&v);
         Py_DECREF(result);
         return 0;
       }
+
       igraph_vs_destroy(&result->vs);
+
       if (igraph_vs_vector_copy(&result->vs, &v)) {
         Py_DECREF(result);
         igraphmodule_handle_igraph_error();
         igraph_vector_destroy(&v);
         return NULL;
       }
+
       igraph_vector_destroy(&v);
     }
   }
