@@ -74,6 +74,7 @@
    /* Put the tokens into the symbol table, so that GDB and other debuggers
       know about them.  */
    enum yytokentype {
+     END = 0,
      ALNUM = 258,
      NEWLINE = 259,
      HASH = 260,
@@ -81,6 +82,7 @@
    };
 #endif
 /* Tokens.  */
+#define END 0
 #define ALNUM 258
 #define NEWLINE 259
 #define HASH 260
@@ -475,8 +477,8 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,    93,    93,    94,    95,    98,   100,   102,   102,   104,
-     109,   118,   123
+       0,    94,    94,    95,    96,    99,   101,   103,   103,   105,
+     110,   119,   124
 };
 #endif
 
@@ -485,9 +487,9 @@ static const yytype_uint8 yyrline[] =
    First, the terminals, then, starting at YYNTOKENS, nonterminals.  */
 static const char *const yytname[] =
 {
-  "$end", "error", "$undefined", "ALNUM", "NEWLINE", "HASH", "ERROR",
-  "$accept", "input", "vertex", "vertexdef", "edges", "edge", "edgeid",
-  "weight", 0
+  "\"end of file\"", "error", "$undefined", "ALNUM", "NEWLINE", "\"#\"",
+  "ERROR", "$accept", "input", "vertex", "vertexdef", "edges", "edge",
+  "edgeid", "weight", 0
 };
 #endif
 
