@@ -74,12 +74,14 @@
    /* Put the tokens into the symbol table, so that GDB and other debuggers
       know about them.  */
    enum yytokentype {
+     END = 0,
      ALNUM = 258,
      NEWLINE = 259,
      ERROR = 260
    };
 #endif
 /* Tokens.  */
+#define END 0
 #define ALNUM 258
 #define NEWLINE 259
 #define ERROR 260
@@ -91,24 +93,24 @@
 
 
 
-/* 
+/*
    IGraph library.
    Copyright (C) 2006-2012  Gabor Csardi <csardi.gabor@gmail.com>
    334 Harvard st, Cambridge, MA, 02138 USA
-   
+
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
-   
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-   
+
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc.,  51 Franklin Street, Fifth Floor, Boston, MA 
+   Foundation, Inc.,  51 Franklin Street, Fifth Floor, Boston, MA
    02110-1301 USA
 
 */
@@ -116,7 +118,7 @@
 #include <stdio.h>
 #include <string.h>
 
-#include "igraph_types.h" 
+#include "igraph_types.h"
 #include "igraph_memory.h"
 #include "igraph_error.h"
 #include "config.h"
@@ -127,9 +129,9 @@
 #include "io/parsers/ncol-lexer.h"
 #include "internal/hacks.h"
 
-int igraph_ncol_yyerror(YYLTYPE* locp, 
-			igraph_i_ncol_parsedata_t *context, 
-			const char *s);
+int igraph_ncol_yyerror(YYLTYPE* locp,
+                        igraph_i_ncol_parsedata_t *context,
+                        const char *s);
 igraph_real_t igraph_ncol_get_number(const char *str, long int len);
 
 #define scanner context->scanner
@@ -472,7 +474,7 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,    93,    93,    94,    95,    98,   103,   111,   116
+       0,    94,    94,    95,    96,    99,   104,   112,   117
 };
 #endif
 
@@ -481,8 +483,8 @@ static const yytype_uint8 yyrline[] =
    First, the terminals, then, starting at YYNTOKENS, nonterminals.  */
 static const char *const yytname[] =
 {
-  "$end", "error", "$undefined", "ALNUM", "NEWLINE", "ERROR", "$accept",
-  "input", "edge", "edgeid", "weight", 0
+  "\"end of file\"", "error", "$undefined", "ALNUM", "NEWLINE", "ERROR",
+  "$accept", "input", "edge", "edgeid", "weight", 0
 };
 #endif
 
@@ -1403,7 +1405,7 @@ yyreduce:
     {
         case 5:
 
-    { 
+    {
            igraph_vector_push_back(context->vector, (yyvsp[(1) - (3)].edgenum));
            igraph_vector_push_back(context->vector, (yyvsp[(2) - (3)].edgenum));
            igraph_vector_push_back(context->weights, 0);
@@ -1412,26 +1414,26 @@ yyreduce:
 
   case 6:
 
-    { 
+    {
            igraph_vector_push_back(context->vector, (yyvsp[(1) - (4)].edgenum));
            igraph_vector_push_back(context->vector, (yyvsp[(2) - (4)].edgenum));
            igraph_vector_push_back(context->weights, (yyvsp[(3) - (4)].weightnum));
-	   context->has_weights = 1;
+           context->has_weights = 1;
        ;}
     break;
 
   case 7:
 
-    { igraph_trie_get2(context->trie, 
-				   igraph_ncol_yyget_text(scanner),
-				   igraph_ncol_yyget_leng(scanner), 
-				   &(yyval.edgenum)); ;}
+    { igraph_trie_get2(context->trie,
+                  igraph_ncol_yyget_text(scanner),
+                  igraph_ncol_yyget_leng(scanner),
+                  &(yyval.edgenum)); ;}
     break;
 
   case 8:
 
-    { (yyval.weightnum)=igraph_ncol_get_number(igraph_ncol_yyget_text(scanner), 
-					    igraph_ncol_yyget_leng(scanner)); ;}
+    { (yyval.weightnum)=igraph_ncol_get_number(igraph_ncol_yyget_text(scanner),
+                        igraph_ncol_yyget_leng(scanner)); ;}
     break;
 
 
@@ -1659,23 +1661,23 @@ yyreturn:
 
 
 
-int igraph_ncol_yyerror(YYLTYPE* locp, 
-			igraph_i_ncol_parsedata_t *context, 
-			const char *s) {
-  snprintf(context->errmsg, sizeof(context->errmsg)/sizeof(char)-1, 
-	   "Parse error in NCOL file, line %i (%s)", 
-	   locp->first_line, s);
-  return 0;
+int igraph_ncol_yyerror(YYLTYPE* locp,
+            igraph_i_ncol_parsedata_t *context,
+            const char *s) {
+    snprintf(context->errmsg, sizeof(context->errmsg)/sizeof(char)-1,
+            "Parse error in NCOL file, line %i (%s)",
+            locp->first_line, s);
+    return 0;
 }
 
 igraph_real_t igraph_ncol_get_number(const char *str, long int length) {
-  igraph_real_t num;
-  char *tmp=IGRAPH_CALLOC(length+1, char);
-  
-  strncpy(tmp, str, length);
-  tmp[length]='\0';
-  sscanf(tmp, "%lf", &num);
-  IGRAPH_FREE(tmp);
-  return num;
-} 
+    igraph_real_t num;
+    char *tmp=IGRAPH_CALLOC(length+1, char);
+
+    strncpy(tmp, str, length);
+    tmp[length]='\0';
+    sscanf(tmp, "%lf", &num);
+    IGRAPH_FREE(tmp);
+    return num;
+}
 
